@@ -79,6 +79,7 @@ const Technology_DB technology_intel[] =
 	{ 10,         122,          -1,          "14 nm" }, // Gemini Lake
 	{ 10,         138,          -1,          "10 nm" }, // Tremont (Lakefield)
 	{ 10,         154,          -1,        "Intel 7" }, // Alder Lake-P / Alder Lake-H
+	{ 10,         170,          -1,        "Intel 4" }, // Meteor Lake-H
 	{ 10,         186,          -1,        "Intel 7" }, // Raptor Lake-P / Raptor Lake-U / Raptor Lake-H
 	{ 11,          11,          -1,        "0.13 µm" }, // PIII Tualatine
 	{ 12,          28,          -1,          "45 nm" }, // Atom Diamondville / Pineview / Silverthorne
@@ -107,6 +108,7 @@ const Technology_DB technology_intel[] =
 	{ 15,          79,          -1,          "14 nm" }, // Broadwell-E
 	{ 15,         143,          -1,        "Intel 7" }, // Sapphire Rapids-WS / Sapphire Rapids-SP
 	{ 15,         191,          -1,        "Intel 7" }, // Raptor Lake-S ("Golden Cove" cores)
+	{ 15,         207,          -1,        "Intel 7" }, // Emerald Rapids-SP
 	{ -2,          -2,          -2,             NULL }
 	//Model        E. Model     E. Family   Process
 };
@@ -154,7 +156,8 @@ const Technology_DB technology_amd[] =
 	{ -1,         104,          23,           "7 nm" }, // Zen 2 (Lucienne)
 	{ -1,         113,          23,           "7 nm" }, // Zen 2 (Matisse)
 	{ -1,         132,          23,           "7 nm" }, // Zen 2 (4800S Desktop Kit)
-	{ -1,         144,          23,           "7 nm" }, // Zen 2 (Custom APU for Steam Deck)
+	{ -1,         144,          23,           "7 nm" }, // Zen 2 (Custom APU 0405 for Steam Deck)
+	{ -1,         145,          23,           "7 nm" }, // Zen 2 (Custom APU 0932 for Steam Deck)
 	{ -1,         160,          23,           "6 nm" }, // Zen 2 (Mendocino)
 	{ -1,          33,          25,           "7 nm" }, // Zen 3 (Vermeer)
 	{ -1,          80,          25,           "7 nm" }, // Zen 3 (Cezanne)
@@ -190,40 +193,43 @@ const Package_DB package_intel[] =
 	{ "Bloomfield",                     NULL,                               "LGA 1366"       },
 	{ NULL,                             "Intel(R) Core(TM)2 Duo CPU E7400", "LGA 775"        },
 	{ NULL,                             "Intel(R) Core(TM)2 Quad CPU Q6600","LGA 775"        },
+	{ NULL,                             "Intel(R) Core(TM) i5-2500K CPU",   "LGA 1155"       },
+	{ NULL,                             "Intel(R) Celeron(R) CPU G550T",    "LGA 1155"       },
 	{ NULL,                             "Intel(R) Core(TM) i5-2520M CPU",   "rPGA 988B"      },
 	{ NULL,                             "Intel(R) Xeon(R) CPU E31275",      "LGA 1155"       },
 	{ NULL,                             "Intel(R) Core(TM) i7-2860QM CPU",  "rPGA 988B"      },
 	{ NULL,                             "Intel(R) Core(TM) i7-3740QM CPU",  "rPGA 988B"      },
-	{ NULL,                             "Intel(R) Core(TM) i5-4300U CPU",   "FCBGA 1168"     },
-	{ NULL,                             "Intel(R) Core(TM) i7-4600U CPU",   "FCBGA 1168"     },
+	{ NULL,                             "Intel(R) Core(TM) i5-4300U CPU",   "BGA 1168"       },
+	{ NULL,                             "Intel(R) Core(TM) i7-4600U CPU",   "BGA 1168"       },
 	{ NULL,                             "Intel(R) Core(TM) i7-4790 CPU",    "LGA 1150"       },
 	{ NULL,                             "Intel(R) Core(TM) i7-5775C CPU",   "LGA 1150"       },
-	{ NULL,                             "Intel(R) Core(TM) i7-6560U CPU",   "FCBGA 1356"     },
+	{ NULL,                             "Intel(R) Core(TM) i7-6560U CPU",   "BGA 1356"       },
 	{ NULL,                             "Intel(R) Core(TM) i5-6400 CPU",    "LGA 1151"       },
-	{ NULL,                             "Intel(R) Core(TM) i7-7300U CPU",   "FCBGA 1356"     },
-	{ NULL,                             "Intel(R) Core(TM) i7-7820HQ CPU",  "FCBGA 1440"     },
-	{ NULL,                             "Intel(R) Core(TM) i7-8250U CPU",   "FCBGA 1356"     },
-	{ NULL,                             "Intel(R) Core(TM) i7-8350U CPU",   "FCBGA 1356"     },
-	{ NULL,                             "Intel(R) Core(TM) i7-8550U CPU",   "FCBGA 1356"     },
-	{ NULL,                             "Intel(R) Core(TM) i7-8650U CPU",   "FCBGA 1356"     },
-	{ NULL,                             "Intel(R) Core(TM) i5-9300H CPU",   "FCBGA 1440"     },
+	{ NULL,                             "Intel(R) Core(TM) i7-7300U CPU",   "BGA 1356"       },
+	{ NULL,                             "Intel(R) Core(TM) i7-7820HQ CPU",  "BGA 1440"       },
+	{ NULL,                             "Intel(R) Core(TM) i7-8250U CPU",   "BGA 1356"       },
+	{ NULL,                             "Intel(R) Core(TM) i7-8350U CPU",   "BGA 1356"       },
+	{ NULL,                             "Intel(R) Core(TM) i7-8550U CPU",   "BGA 1356"       },
+	{ NULL,                             "Intel(R) Core(TM) i7-8650U CPU",   "BGA 1356"       },
+	{ NULL,                             "Intel(R) Core(TM) i5-9300H CPU",   "BGA 1440"       },
 	{ NULL,                             "Intel(R) Core(TM) i9-9900K CPU",   "LGA 1151"       },
 	{ NULL,                             "Intel(R) Core(TM) i5-10500 CPU",   "LGA 1200"       },
-	{ NULL,                             "Intel(R) Core(TM) i5-1135G7",      "FCBGA 1449"     },
-	{ NULL,                             "Intel(R) Core(TM) i7-1165G7",      "FCBGA 1449"     },
+	{ NULL,                             "Intel(R) Core(TM) i5-1135G7",      "BGA 1449"       },
+	{ NULL,                             "Intel(R) Core(TM) i7-1165G7",      "BGA 1449"       },
 	{ NULL,                             "Intel(R) Core(TM) i7-11700K",      "LGA 1200"       },
-	{ NULL,                             "Intel(R) Core(TM) i3-1220P",       "FCBGA 1744"     },
+	{ NULL,                             "Intel(R) Core(TM) i9-11900K",      "LGA 1200"       },
+	{ NULL,                             "Intel(R) Core(TM) i3-1220P",       "BGA 1744"       },
 	{ NULL,                             "Intel(R) Core(TM) i5-12400",       "LGA 1700"       },
-	{ NULL,                             "Intel(R) Core(TM) i7-12700H",      "FCBGA 1744"     },
+	{ NULL,                             "Intel(R) Core(TM) i7-12700H",      "BGA 1744"       },
 	{ NULL,                             "Intel(R) Core(TM) i7-12700KF",     "LGA 1700"       },
 	{ NULL,                             "Intel(R) Core(TM) i9-12900K",      "LGA 1700"       },
-	{ NULL,                             "Intel(R) Core(TM) i9-12900HK",     "FCBGA 1744"     },
+	{ NULL,                             "Intel(R) Core(TM) i9-12900HK",     "BGA 1744"       },
 	{ NULL,                             "Intel(R) Core(TM) i5-13600K",      "LGA 1700"       },
 	{ NULL,                             "Intel(R) Core(TM) i7-13700K",      "LGA 1700"       },
 	{ NULL,                             "Intel(R) Core(TM) i9-13900K",      "LGA 1700"       },
-	{ NULL,                             "Intel(R) Celeron(R) CPU N2930",    "FCBGA 1170"     },
-	{ NULL,                             "Intel(R) Celeron(R) CPU N3350",    "FCBGA 1296"     },
-	{ NULL,	                            "Intel(R) Celeron(R) N4000",        "FCBGA 1090"     },
+	{ NULL,                             "Intel(R) Celeron(R) CPU N2930",    "BGA 1170"       },
+	{ NULL,                             "Intel(R) Celeron(R) CPU N3350",    "BGA 1296"       },
+	{ NULL,	                            "Intel(R) Celeron(R) N4000",        "BGA 1090"       },
 	{ NULL,                             "Intel(R) Core(TM) i5-3470 CPU",    "LGA 1155"       },
 	{ NULL,                             "Intel(R) Core(TM) i7-4770 CPU",    "LGA 1155"       },
 	{ NULL,                             "Intel(R) Core(TM) i3-4350 CPU",    "LGA 1150"       },
@@ -240,16 +246,37 @@ const Package_DB package_intel[] =
 const Package_DB package_amd[] =
 {
 	//Codename                          Model            Socket
-	{ "Athlon 64 FX X2 (Toledo)",       NULL,            "939 (PGA-ZIF)"  },
-	{ "Kabini X4",                      "Athlon",        "AM1 (PGA-ZIF)"  },
-	{ "Kabini X4",                      "Sempron",       "AM1 (PGA-ZIF)"  },
-	{ "Trinity X4",                     NULL,            "FM2 (PGA-ZIF)"  },
-	{ "Turion X2",                      "TL",            "S1g1 (PGA-ZIF)" },
-	{ "Turion X2",                      "TK",            "S1g1 (PGA-ZIF)" },
-	{ "Deneb",    "AMD Phenom(tm) II X4 945",            "AM3 (PGA-938)"  },
-	{ "Athlon II X4 (Propus)",          NULL,            "AM3 (PGA-938)"  },
+	/* K8 */
+	{ "Athlon 64 FX X2 (Toledo)",       NULL,            "939 (PGA-939)"  },
+	{ "Turion X2",                      "TL",            "S1g1 (PGA-638)" },
+	{ "Turion X2",                      "TK",            "S1g1 (PGA-638)" },
+	/* K10 */
+	  /* Desktop */
+	{ "Kuma",                          NULL,             "AM2+ (PGA-940)" }, // 2008-2009, 65 nm
+	{ "Agena",                         NULL,             "AM2+ (PGA-940)" }, // 2007-2008, 65 nm
+	{ "Toliman",                       NULL,             "AM2+ (PGA-940)" }, // 2008, 65 nm
+	{ "Thuban",                        NULL,             "AM3 (PGA-938)"  }, // 2010, 45 nm
+	{ "Zosma",                         NULL,             "AM3 (PGA-938)"  }, // 2010-2011, 45 nm
+	{ "Deneb",          "AMD Phenom(tm) II X4 920",      "AM2+ (PGA-940)" }, // 2009, 45 nm
+	{ "Deneb",          "AMD Phenom(tm) II X4 940",      "AM2+ (PGA-940)" }, // 2009, 45 nm
+	{ "Deneb",                         NULL,             "AM3 (PGA-938)"  }, // 2009-2011, 45 nm
+	{ "Propus",                        NULL,             "AM3 (PGA-938)"  }, // 2009-2011, 45 nm
+	{ "Heka",           "AMD Phenom(tm) II X3 715",      "AM2+ (PGA-940)" }, // 2009, 45 nm
+	{ "Heka",                          NULL,             "AM3 (PGA-938)"  }, // 2009-2010, 45 nm
+	{ "Callisto",                      NULL,             "AM3 (PGA-938)"  }, // 2009-2011, 45 nm
+	{ "Rana",                          NULL,             "AM3 (PGA-938)"  }, // 2009-2011, 45 nm
+	{ "Sargas",                        NULL,             "AM3 (PGA-938)"  }, // 2009-2011, 45 nm
+	{ "Regor",                         NULL,             "AM3 (PGA-938)"  }, // 2009-2013, 45 nm
+	  /* Mobile */
+	{ "Caspian",                       NULL,             "S1g3 (PGA-638)" }, // 2009-2010, 45 nm
+	{ "Champlain",                     NULL,             "S1g4 (PGA-638)" }, // 2010-2011, 45 nm
+	{ "Geneva",                        NULL,             "S1g4 (PGA-638)" }, // 2010-2011, 45 nm
+	/* Bulldozer */
 	{ "Zambezi",                        NULL,            "AM3+ (PGA-942)" },
 	{ "Vishera",                        NULL,            "AM3+ (PGA-942)" },
+	{ "Kabini X4",                      "Athlon",        "AM1 (PGA-721)"  },
+	{ "Kabini X4",                      "Sempron",       "AM1 (PGA-721)"  },
+	{ "Trinity X4",                     NULL,            "FM2 (PGA-904)"  },
 	/* Zen */
 	{ "Naples",                         NULL,            "SP3 (LGA-4094)"   },
 	{ "Whitehaven",                     NULL,            "SP3r2 (LGA-4094)" },
